aboutsummaryrefslogtreecommitdiff
path: root/smartpen.h
diff options
context:
space:
mode:
Diffstat (limited to 'smartpen.h')
-rw-r--r--smartpen.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/smartpen.h b/smartpen.h
index 2ff64e3..e3dadad 100644
--- a/smartpen.h
+++ b/smartpen.h
@@ -45,18 +45,21 @@ public:
bool isConnected() const;
- enum Parameter : quint16 {
- /// The offset between the PenTime (see below) and the user's configured time. This value is static.
- PenUserTime = 0x8003,
+ enum class Parameter : quint16 {
+ Id = 0x0000,
+ /// The offset between the RtcTime (see below) and the user's configured time. This value is fixed at setup time.
+ UserTime = 0x8003,
/// The current time as reported by the pen's rtc
- PenRtcTime = 0x8004,
- PenType = 0x8006,
- PenName = 0x8011
+ RtcTime = 0x8004,
+ Type = 0x8006,
+ Name = 0x8011
};
QByteArray getObject(const QString& name);
QByteArray getParameter(Parameter parameter);
+ PenId getPenId();
+ QString getPenSerial();
QString getPenName();
PenTime getPenTime(Parameter parameter);